@@ -13,6 +13,9 @@
 #include <dir.h>		/* last choice */
 #else	/* SYS5DIR */
 #include <dirent.h>
+#ifdef linux
+#define direct dirent
+#endif /* linux */
 #endif
 #else	/* NDIR */
 #include <ndir.h>
