@@ -1,6 +1,6 @@
 /* smail.c - MH interface to SendMail/SMTP */
 #ifndef	lint
-static char ident[] = "@(#)$Id: smail.c,v 1.27 1993/12/01 03:50:31 jromine Exp $";
+static char ident[] = "@(#)$Id: smail.c,v 1.29 1995/12/06 22:29:38 jromine Exp $";
 #endif
 
 /* LINTLIBRARY */
@@ -305,15 +305,13 @@ int	watch,
 	goto send_options;
 
     if (client == NULL || *client == '\0')
-	client = clientname;
+	if (clientname)
+	    client = clientname;
+	else
+	    client = LocalName ();	/* no clientname -> LocalName */
 #ifdef ZMAILER
     if (client == NULL || *client == '\0')
 	client = "localhost";
-#else
-#if	!defined(SENDMTS) || defined(MMDFII) || defined(SVR4)
-    if (client == NULL || *client == 0)
-	client = LocalName ();
-#endif
 #endif	/* not ZMAILER */
 
     if ((sd1 = rclient (server, "tcp", "smtp")) == NOTOK)
@@ -1055,6 +1053,7 @@ char   *fmt,
 static int  smtalk (time, fmt, a, b, c, d)
 register int     time;
 register char   *fmt;
+register char   *a, *b, *c, *d;
 {
     register int    result;
     char    buffer[BUFSIZ];
