@@ -48,8 +48,12 @@ FILE   *io;
 
 #ifdef _FSTDIO
     fpurge (io);
+#else
+#ifdef _STDIO_USES_IOSTREAM
+    io -> _IO_write_ptr = io -> _IO_write_base;
 #else
     if (io -> _ptr = io -> _base)
 	io -> _cnt = 0;
 #endif
+#endif /* _STDIO_USES_IOSTREAM */
 }
