@@ -241,14 +241,25 @@ register FILE   *inb;
 		 */
 	body: 	;
 		while (state == BODY) {
+#ifdef _STDIO_USES_IOSTREAM
+		    if (scnout->_IO_write_ptr == scnout->_IO_write_end) {
+#else
 		    if (scnout->_cnt <= 0) {
+#endif
 			if (fflush(scnout) == EOF)
 			    adios (scnmsg, "write error on");
 		    }
+#ifdef _STDIO_USES_IOSTREAM
+		    state = m_getfld(state, name, scnout->_IO_write_ptr,
+				     (long)scnout->_IO_write_ptr-(long)scnout->_IO_write_end,
+				     inb);
+		    scnout->_IO_write_ptr += msg_count;
+#else
 		    state = m_getfld( state, name, scnout->_ptr,
 				      -(scnout->_cnt), inb );
 		    scnout->_cnt -= msg_count;
 		    scnout->_ptr += msg_count;
+#endif
 		}
 		goto finished;
 
